@@ -28,7 +28,7 @@ use v5.12.5;
 #     1;
 # };
 
-our $VERSION = eval '0.3';
+our $VERSION = eval '0.4';
 
 =head1 NAME
 
@@ -36,7 +36,7 @@ NetAddr::IP::FastNew - NetAddr::IP new() methods with no validation
 
 =head1 VERSION
 
-0.3
+0.4
 
 =head1 SYNOPSIS
 
@@ -264,8 +264,7 @@ sub new {
 =head2 new_ipv4
 
 Create a real NetAddr::IP from a single IPv4 address with almost no
-validation.  This has more overhead than the FastNew new() but it's much
-faster if you make use of the IP object.
+validation.
 
 This only takes one argument, the single IP address.  Anything else will fail
 in (probably) bad ways.  Validation is completely up to you and is not done
